@@ -1,13 +1,7 @@
 # My::Builder
 #  A local Module::Build subclass for installing libjio
 #
-# $Id: Builder.pm 7526 2009-06-14 16:50:50Z FREQUENCY@cpan.org $
-#
-# By Jonathan Yu <frequency@cpan.org>, 2009. All rights reversed.
-#
-# This package and its contents are released by the author into the Public
-# Domain, to the full extent permissible by law. For additional information,
-# please see the included `LICENSE' file.
+# $Id: Builder.pm 8633 2009-08-18 16:00:58Z FREQUENCY@cpan.org $
 
 package My::Builder;
 
@@ -81,4 +75,15 @@ sub ACTION_install {
   return $rc;
 }
 
+sub ACTION_clean {
+  my ($self) = @_;
+
+  my $rc = $self->SUPER::ACTION_clean;
+  _chdir_or_die('libjio');
+  $rc = (system($self->notes('make'), 'clean') == 0) ? 1 : 0;
+  _chdir_back();
+
+  return $rc;
+}
+
 1;
